@@ -5,7 +5,7 @@ import click
 from tabulate import tabulate
 
 from . import MySQLtoSQLite
-from .click_utils import OptionEatAll
+from .click_utils import OptionEatAll, prompt_password
 from .debug_info import info
 
 
@@ -22,7 +22,15 @@ from .debug_info import info
     "-d", "--mysql-database", default=None, help="MySQL database name", required=True
 )
 @click.option("-u", "--mysql-user", default=None, help="MySQL user", required=True)
-@click.option("-p", "--mysql-password", default=None, help="MySQL password")
+@click.option(
+    "-p",
+    "--prompt-mysql-password",
+    is_flag=True,
+    default=False,
+    callback=prompt_password,
+    help="Prompt for MySQL password",
+)
+@click.option("--mysql-password", default=None, help="MySQL password")
 @click.option(
     "-t",
     "--mysql-tables",
@@ -39,6 +47,9 @@ from .debug_info import info
 @click.option(
     "-P", "--mysql-port", type=int, default=3306, help="MySQL port. Defaults to 3306."
 )
+@click.option(
+    "-S", "--skip-ssl", is_flag=True, help="Disable MySQL connection encryption."
+)
 @click.option(
     "-c",
     "--chunk",
@@ -61,39 +72,45 @@ from .debug_info import info
     "can be useful in situations where multiple queries, with small "
     "result sets, need to be combined or computed with each other.",
 )
+@click.option("-q", "--quiet", is_flag=True, help="Quiet. Display only errors.")
 @click.version_option(
     message=tabulate(info(), headers=["software", "version"], tablefmt="github")
 )
-def cli(  # noqa: ignore=C0330  # pylint: disable=C0330,R0913
+def cli(
     sqlite_file,
     mysql_user,
+    prompt_mysql_password,
     mysql_password,
     mysql_database,
     mysql_tables,
     without_foreign_keys,
     mysql_host,
     mysql_port,
+    skip_ssl,
     chunk,
     log_file,
     vacuum,
     use_buffered_cursors,
+    quiet,
 ):
     """Transfer MySQL to SQLite using the provided CLI options."""
     try:
         converter = MySQLtoSQLite(
             sqlite_file=sqlite_file,
             mysql_user=mysql_user,
-            mysql_password=mysql_password,
+            mysql_password=mysql_password or prompt_mysql_password,
             mysql_database=mysql_database,
             mysql_tables=mysql_tables,
             without_foreign_keys=without_foreign_keys
             or (mysql_tables is not None and len(mysql_tables) > 0),
             mysql_host=mysql_host,
             mysql_port=mysql_port,
+            mysql_ssl_disabled=skip_ssl,
             chunk=chunk,
             vacuum=vacuum,
             buffered=use_buffered_cursors,
             log_file=log_file,
+            quiet=quiet,
         )
         converter.transfer()
     except KeyboardInterrupt:
